(***********************************************************************)
(*                                                                     *)
(*                               Grimage                               *)
(*                                                                     *)
(*                           Graphics image                            *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2014-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: grimage.mli,v 1.9 2014/02/27 16:45:22 fclement Exp $ *)

(** Interface of images from this library with images of the Caml
    [Graphics] library. *)

open Generic_image;;

type grimage = Generic_image.image;;
type t = grimage;;

val pixmap_of_grimage : image -> pixmap;;
 (** Convert a [Grimage.t] value to an array of colors. *)
val grimage_of_pixmap : pixmap -> grimage;;
 (** Convert a pixmap to a [Grimage.grimage] image. *)

val image_of_grimage : grimage -> Graphics.image;;
 (** Convert a [Grimage.t] value to an image for [Graphics]. *)
val grimage_of_image : Graphics.image -> grimage;;
 (** The converse convertion. *)

val load_ppm_grimage : file_name -> grimage;;
  (** Load a  ppm image as a Caml value of type [Grimage.grimage]. *)
val load_bmp_grimage : file_name -> grimage;;
  (** Load a  bmp image as a Caml value of type [Grimage.grimage]. *)

val save_bmp_grimage : file_name -> grimage -> unit;;
  (** Save a [Grimage.grimage] Caml value as an image in the bmp format. *)
val save_ppm_grimage : file_name -> grimage -> unit;;
  (** Save a [Grimage.grimage] Caml value as an image in the ppm format. *)

val draw_bmp : Bmp.bmp -> x -> y -> unit;;
  (** A short hand to draw a bmp format encoded image into the [Graphics]
      window. *)
val draw_ppm : Ppm.ppm -> x -> y -> unit;;
  (** A short hand to draw a portable pixmap format encoded image the
      [Graphics] window. *)

val draw_grimage : grimage -> x -> y -> unit;;
  (** Draw an image from this library (i.e. a [Grimage.grimage] value)
      into the graphic window at the specified coordinates. *)

val draw_bmp_file : file_name -> x -> y -> unit;;
  (** A short hand to draw a bmp format encoded image contained in the
      given file into the [Graphics] window. *)

val draw_ppm_file : file_name -> x -> y -> unit;;
  (** A short hand to draw a portable pixmap file image contained in
      the given file into the [Graphics] window. *)

val image_of_screen : unit -> Graphics.image
  (** Save the contents of the [Graphics] screen in a [Graphics] image. *)
;;

val screen_of_image : Graphics.image -> unit
  (** Restore the contents of the [Graphics] screen from the [Graphics] image
    argument. *)
;;

val save_screen_bmp : file_name -> unit;;
  (** Save the contents of the [Graphics] screen as a bmp image in the
  file given. *)

val save_screen_ppm : file_name -> unit;;
  (** Save the contents of the [Graphics] screen as a ppm image in the
  file given. *)

val restore_screen_bmp : file_name -> unit;;
  (** Draw the contents of the [Graphics] screen found as a bmp image in the
  file given. *)

val restore_screen_ppm : file_name -> unit;;
  (** Draw the contents of the [Graphics] screen found as a ppm image in the
  file given. *)
