(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: uarray1_with_c_layout.ml,v 1.13 2014/02/09 17:27:28 fclement Exp $ *)

(* More operations on one-dimensional bigarrays with C layout. *)

let a1c_qual = Upervasives.qualify "Uarray1_with_c_layout";;

let a1c_invalid_arg fun_name =
  Upervasives.invalid_arg_qual a1c_qual fun_name ""
;;

open Bigarray;;

let length = Array1.dim
and get = Array1.get
and set = Array1.set;;

let init kind n f =
  let a = Array1.create kind c_layout n in
  for i = 0 to n - 1 do set a i (f i) done;
  a;;

let make kind n x =
  let a = Array1.create kind c_layout n in
  Array1.fill a x;
  a;;

(* Iterators. *)

let iter f a =
  let n = length a in
  for i = 0 to n - 1 do f (get a i) done;;

let map f a =
  let n = length a in
  let b = Array1.create (Array1.kind a) c_layout n in
  for i = 0 to n - 1 do set b i (f (get a i)) done;
  b;;

let fold_left f x a =
  let n = length a in
  let r = ref x in
  for i = 0 to n - 1 do r := f !r (get a i) done;
  !r;;

(* Iterators on two bigarrays. *)

let same_length fun_name a1 a2 =
  let n = length a1 in
  if n = length a2 then n else
  a1c_invalid_arg fun_name;;

let fold_left2 f x a1 a2 =
  let n = same_length "fold_left2" a1 a2 in
  let r = ref x in
  for i = 0 to n - 1 do r := f !r (get a1 i) (get a2 i) done;
  !r;;
